# 创建 ES 和 Kibana 容器

### 单机模式
```yaml
version: '3'
services:
  elasticsearch:
    image: docker.elastic.co/elasticsearch/elasticsearch:7.17.0
    container_name: elasticsearch
    environment:
      - node.name=es-node
      - cluster.name=es-cluster
      - discovery.type=single-node
      - xpack.security.enabled=false
      - "ES_JAVA_OPTS=-Xms512m -Xmx512m"
    volumes:
      - esdata:/var/lib/docker/volumes/elastic_data/_data
    ports:
      - "9200:9200"
      - "9300:9300"
    restart: always
    ulimits:
      memlock:
        soft: -1
        hard: -1
    networks:
      - elastic-net

  kibana:
    image: docker.elastic.co/kibana/kibana:7.17.0
    container_name: kibana
    environment:
      - ELASTICSEARCH_HOSTS=http://elasticsearch:9200
      - SERVER_NAME=kibana.example.com
      - XPACK_SECURITY_ENABLED=false
    ports:
      - "5601:5601"
    restart: always
    depends_on:
      - elasticsearch
    networks:
      - elastic-net

volumes:
  esdata:
    driver: local
networks:
  elastic-net:
```
+ 这里指定了 `ulimits`，`memlock` 限制了内存锁的大小，`soft` 和 `hard` 分别表示软限制和硬限制，`-1` 表示不限制，否则es启动会报错
```yaml
ulimits:
  memlock:
    soft: -1
    hard: -1
```